check_mean — skchange

Skip to main content
`Ctrl`+`K`

# check_mean

check_mean(mean: _SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number, X: ndarray) → ndarray

  Check if the fixed mean parameter is valid.

  Parameters:
    meannp.ndarray or numbers.Number

      Fixed mean for the cost calculation.

    Xnp.ndarray

      2d input data.

  Returns:
    meannp.ndarray

      Fixed mean for the cost calculation.